Phantoms
========
This module contains simple artificial data generation methods. These data can be isotropic or based on provided magnetics data. Method for creation of artificial magnetic data similar to circular or elliptic plasma is included. 

.. automodule :: tomotok.core.phantoms
    :members:
    :noindex: